diff src/video/riscos/SDL_riscosevents.c @ 1035:974ba6ae0fa3

Date: Wed, 26 Jan 2005 13:37:09 GMT From: Peter Naulls Subject: RISC OS SDL Patches Sam, I've attached a diff of the latest changes to libSDL for RISC OS support. These changes are by Alan Buckley and myself. The most significant of these are: Optimised assembler blit rountines - I've attached the file src/video/riscos/SDL_riscosASM.s which is needed for this. Move to using /dev/dsp instead of its own audio implementation. This means that src/audio/riscos/SDL_drenderer.c should be removed Typo fixes. Mainly correct spelling of "RISC OS", but some from elsewhere too.
author Sam Lantinga <slouken@libsdl.org>
date Sat, 12 Feb 2005 18:01:31 +0000
parents d74fbf56f2f6
children c9b51268668f
line wrap: on
line diff
--- a/src/video/riscos/SDL_riscosevents.c	Sat Jan 29 09:58:40 2005 +0000
+++ b/src/video/riscos/SDL_riscosevents.c	Sat Feb 12 18:01:31 2005 +0000
@@ -21,7 +21,7 @@
 */
 
 /*
-     File added by Alan Buckley (alan_baa@hotmail.com) for RISCOS compatability
+     File added by Alan Buckley (alan_baa@hotmail.com) for RISC OS compatability
 	 27 March 2003
 
      Implements keyboard setup, event pump and keyboard and mouse polling
@@ -43,10 +43,10 @@
 #include "kernel.h"
 #include "swis.h"
 
 /* The translation table from a RISCOS internal key numbers to a SDL keysym */
 static SDLKey RO_keymap[SDLK_LAST];
 
 /* RISCOS Key codes */
 #define ROKEY_SHIFT 0
 #define ROKEY_CTRL  1
 #define ROKEY_ALT   2
@@ -90,7 +90,7 @@
 	RISCOS_PollKeyboard();
 	RISCOS_PollMouse(this);
 #ifdef DISABLE_THREADS
-	DRenderer_FillBuffers();
+//	DRenderer_FillBuffers();
 	if (SDL_timer_running) RISCOS_CheckTimer();
 #endif
 }
@@ -262,9 +262,11 @@
        Sint16 new_x = regs.r[0]; /* Initialy get as OS units */
        Sint16 new_y = regs.r[1];
 
-/* Discard mouse events until the let go of the mouse after starting */
-       if (starting && regs.r[2] != 0) return;
-       else starting = 0;
+       /* Discard mouse events until they let go of the mouse after starting */
+       if (starting && regs.r[2] != 0)
+         return;
+       else
+         starting = 0;
 
        if (new_x != last_x || new_y != last_y || last_buttons != regs.r[2])
        {
@@ -43,10 +43,10 @@
 #include "swis.h"
 
-/* The translation table from a RISCOS internal key numbers to a SDL keysym */
+/* The translation table from a RISC OS internal key numbers to a SDL keysym */
 static SDLKey RO_keymap[SDLK_LAST];
 
@@ -43,10 +43,10 @@
 static SDLKey RO_keymap[SDLK_LAST];
 
-/* RISCOS Key codes */
+/* RISC OS Key codes */
 #define ROKEY_SHIFT 0
 #define ROKEY_CTRL  1